#
# spec file for package gstreamer-validate
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   gst-validate
Name:           gstreamer-validate
Version:        1.12.5
Release:        lp150.1.1
Summary:        Validate GStreamer Pipelines
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            http://gstreamer.freedesktop.org
Source:         https://gstreamer.freedesktop.org/src/%{_name}/%{_name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.12.0
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= 1.12.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.12.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:  pkgconfig(json-glib-1.0)

%description
The goal of GstValidate is to be able to detect when elements are not
behaving as expected and report it to the user so he knows how things
are supposed to work inside a GstPipeline. In the end, fixing issues
found by the tool will ensure that all elements behave all together in
the expected way.

The easiest way of using GstValidate is to use one of its command-line
tools, located at tools/ directory. It is also possible to monitor
GstPipelines from any application by using the LD_PRELOAD gstvalidate
lib. The third way of using it is to write your own application that
links and uses libgstvalidate.

%package -n libgstvalidate-1_0-0
Summary:        Validate GStreamer Pipelines -- System Libraries
# all the nice validator scripts live in the main package
Group:          System/Libraries
Recommends:     %{name}

%description -n libgstvalidate-1_0-0
The goal of GstValidate is to be able to detect when elements are not
behaving as expected and report it to the user so he knows how things
are supposed to work inside a GstPipeline. In the end, fixing issues
found by the tool will ensure that all elements behave all together in
the expected way.

%package -n typelib-1_0-GstValidate-1_0
Summary:        Validate GStreamer Pipelines -- GObject Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GstValidate-1_0
The goal of GstValidate is to be able to detect when elements are not
behaving as expected and report it to the user so he knows how things
are supposed to work inside a GstPipeline. In the end, fixing issues
found by the tool will ensure that all elements behave all together in
the expected way.

%package devel
Summary:        Validate GStreamer Pipelines -- Developer's files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libgstvalidate-1_0-0 = %{version}
Requires:       typelib-1_0-GstValidate-1_0 = %{version}

%description devel
The goal of GstValidate is to be able to detect when elements are not
behaving as expected and report it to the user so he knows how things
are supposed to work inside a GstPipeline. In the end, fixing issues
found by the tool will ensure that all elements behave all together in
the expected way.

%prep
%setup -q -n %{_name}-%{version}

%build
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libgstvalidate-1_0-0 -p /sbin/ldconfig
%postun -n libgstvalidate-1_0-0 -p /sbin/ldconfig

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/gst-validate-1.0
%{_bindir}/gst-validate-images-check-1.0
%{_bindir}/gst-validate-launcher
%{_bindir}/gst-validate-media-check-1.0
%{_bindir}/gst-validate-transcoding-1.0
%{_libdir}/gst-validate-launcher/
%dir %{_datadir}/gstreamer-1.0/
%{_datadir}/gstreamer-1.0/validate/
%dir %{_libdir}/gstreamer-1.0/
%dir %{_libdir}/gstreamer-1.0/validate/

%files -n libgstvalidate-1_0-0
%{_libdir}/libgstvalidate-1.0.so.*
%{_libdir}/libgstvalidate-default-overrides-1.0.so.*
%{_libdir}/libgstvalidatevideo-1.0.so.*

%files -n typelib-1_0-GstValidate-1_0
%{_libdir}/girepository-1.0/GstValidate-1.0.typelib

%files devel
%{_datadir}/gir-1.0/GstValidate-1.0.gir
%{_datadir}/gtk-doc/html/gst-validate-1.0
%{_datadir}/gtk-doc/html/gst-validate-plugins-1.0/
%{_includedir}/gstreamer-1.0/
%{_libdir}/gstreamer-1.0/libgstvalidatetracer.so
%{_libdir}/gstreamer-1.0/validate/libgstvalidatefaultinjection.so
%{_libdir}/gstreamer-1.0/validate/libgstvalidategapplication.so
%{_libdir}/gstreamer-1.0/validate/libgstvalidategtk.so
%{_libdir}/gstreamer-1.0/validate/libgstvalidatessim.so
%{_libdir}/pkgconfig/gst-validate-1.0.pc
%{_libdir}/libgstvalidate-1.0.so
%{_libdir}/libgstvalidate-default-overrides-1.0.so
%{_libdir}/libgstvalidatevideo-1.0.so

%changelog
* Fri Mar 30 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + Various bugfixes.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + No changes, stable version bump only.
* Wed Dec  6 2017 dimstar@opensuse.org
- Drop pkgconfig(libgee-1.0) BuildRequires: the build system makes
  no reference to libgee anymore.
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + launcher: Automatically disable output coloration if not
    supported.
  + meson: Fix the way we set the testsuite version.
  + validate:launcher: Use the number of failed test as exit code.
* Fri Jul 14 2017 zaitor@opensuse.org
- Update to version 1.12.2:
  + Bugs fixed: bgo#764025.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + validate: Target the 1.12 integration testsuite.
  + Fixup version in meson.build.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + launcher: Allow using the base launcher as a test manager.
  + tools: Fix dotfile name.
- Changes from version 1.11.91:
  + Bugs fixed: bgo#781213.
- Changes from version 1.11.90:
  + Misc fixes.
* Sat Feb 25 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + Bugs fixed: bgo#778279, bgo#777938, bgo#777977.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + Bugs fixed: bgo#773898.
- Drop pkgconfig(gstreamer-video-1.0) BuildRequires following
  upstream changes.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + Testsuite fixes.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + Bugs fixed: bgo#776280.
* Sat Dec  3 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + Minor bugfixes.
* Sun Nov 27 2016 zaitor@opensuse.org
- Update to version 1.10.1:
  + Meson update.
- Changes from version 1.10.0:
  + Bugs fixed: bgo#772439, bgo#772543.
- Add pkgconfig(json-glib-1.0) BuildRequires: New dependency.
* Wed Aug 24 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + Fix Validate plugin paths mixup.
  + No execute ON_ADDITION if a previous action is executed
    playback_time.
- Drop gstreamer-validate-correctplugindir.patch: Fixed upstream.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + configure: Properly set the current validate testsuite to 1.8.
  + validate: Stop using deprecated method.
* Mon Jun 13 2016 novell@mirell.de
- Add gstreamer-validate-correctplugindir.patch from upstream
  to fix Pitivi startup on some systems.
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + bgo#764192: gst-validate build error on Mac OS X due to missing
    linking to GIO.
* Sat Mar 26 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
- Add explicit pkgconfig(gee-1.0) BuildRequires following upstreams
  configure.
- Replace gobject-introspection-devel for
  pkgconfig(gobject-introspection-1.0) BuildRequires.
* Thu Nov 26 2015 dimstar@opensuse.org
- Initial package, version 1.6.0.
